package com.pdaaphm.biz.service;

import java.util.List;
import com.pdaaphm.biz.domain.SubAlgorithm;

/**
 * 子算法Service接口
 * 
 * @author xlk
 * @date 2023-07-26
 */
public interface ISubAlgorithmService 
{
    /**
     * 查询子算法
     * 
     * @param id 子算法主键
     * @return 子算法
     */
    public SubAlgorithm selectSubAlgorithmById(Long id);

    /**
     * 查询子算法列表
     * 
     * @param subAlgorithm 子算法
     * @return 子算法集合
     */
    public List<SubAlgorithm> selectSubAlgorithmList(SubAlgorithm subAlgorithm);

    /**
     * 新增子算法
     * 
     * @param subAlgorithm 子算法
     * @return 结果
     */
    public int insertSubAlgorithm(SubAlgorithm subAlgorithm);

    /**
     * 修改子算法
     * 
     * @param subAlgorithm 子算法
     * @return 结果
     */
    public int updateSubAlgorithm(SubAlgorithm subAlgorithm);

    /**
     * 批量删除子算法
     * 
     * @param ids 需要删除的子算法主键集合
     * @return 结果
     */
    public int deleteSubAlgorithmByIds(Long[] ids);

    /**
     * 删除子算法信息
     * 
     * @param id 子算法主键
     * @return 结果
     */
    public int deleteSubAlgorithmById(Long id);
}
